@@ -8,12 +8,15 @@
 #pragma once
 
 #include <QObject>
+#include <QQmlEngine>
 #include <QSqlQuery>
 #include <QString>
 
 class Database : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     static Database &instance()
@@ -21,6 +24,11 @@ public:
         static Database _instance;
         return _instance;
     }
+    static Database *create(QQmlEngine *engine, QJSEngine *)
+    {
+        engine->setObjectOwnership(&instance(), QQmlEngine::CppOwnership);
+        return &instance();
+    }
 
     static void openDatabase(const QString &connectionName = QLatin1String(QSqlDatabase::defaultConnection));
     static void closeDatabase(const QString &connectionName = QLatin1String(QSqlDatabase::defaultConnection));
@@ -45,6 +53,7 @@ private:
     bool migrateTo7();
     bool migrateTo8();
     bool migrateTo9();
+    bool migrateTo10();
     void cleanup();
     void setWalMode();
 
