@@ -7,13 +7,15 @@
 
 #include <QVariant>
 
-#include "author.h"
+#include <KLocalizedString>
+
 #include "database.h"
 #include "datamanager.h"
 #include "error.h"
 #include "feed.h"
 #include "feedlogging.h"
 #include "fetcher.h"
+#include "models/abstractepisodeproxymodel.h"
 
 Feed::Feed(const QString &feedurl)
     : QObject(&DataManager::instance())
@@ -37,6 +39,7 @@ Feed::Feed(const QString &feedurl)
     m_deleteAfterCount = query.value(QStringLiteral("deleteAfterCount")).toInt();
     m_deleteAfterType = query.value(QStringLiteral("deleteAfterType")).toInt();
     m_notify = query.value(QStringLiteral("notify")).toBool();
+    int filterTypeValue = query.value(QStringLiteral("filterType")).toInt();
     m_dirname = query.value(QStringLiteral("dirname")).toString();
 
     m_errorId = 0;
@@ -96,55 +99,46 @@ Feed::Feed(const QString &feedurl)
     });
 
     m_entries = new EntriesProxyModel(this);
-}
 
-Feed::~Feed()
-{
+    // restore saved filter
+    AbstractEpisodeProxyModel::FilterType filterType = AbstractEpisodeProxyModel::FilterType(filterTypeValue);
+    if (filterType != m_entries->filterType()) {
+        m_entries->setFilterType(filterType);
+    }
+
+    // save filter to db when changed
+    connect(m_entries, &EntriesProxyModel::filterTypeChanged, this, [this]() {
+        int filterTypeValue = static_cast<int>(m_entries->filterType());
+
+        QSqlQuery writeQuery;
+        writeQuery.prepare(QStringLiteral("UPDATE Feeds SET filterType=:filterType WHERE url=:feedurl;"));
+        writeQuery.bindValue(QStringLiteral(":feedurl"), m_url);
+        writeQuery.bindValue(QStringLiteral(":filterType"), filterTypeValue);
+        Database::instance().execute(writeQuery);
+    });
 }
 
 void Feed::updateAuthors()
 {
-    QVector<Author *> newAuthors;
-    bool haveAuthorsChanged = false;
+    QStringList authors;
 
     QSqlQuery authorQuery;
-    authorQuery.prepare(QStringLiteral("SELECT * FROM Authors WHERE id='' AND feed=:feed"));
+    authorQuery.prepare(QStringLiteral("SELECT name FROM Authors WHERE id='' AND feed=:feed"));
     authorQuery.bindValue(QStringLiteral(":feed"), m_url);
     Database::instance().execute(authorQuery);
     while (authorQuery.next()) {
-        // check if author already exists, if so, then reuse
-        bool existingAuthor = false;
-        QString name = authorQuery.value(QStringLiteral("name")).toString();
-        QString email = authorQuery.value(QStringLiteral("email")).toString();
-        QString url = authorQuery.value(QStringLiteral("uri")).toString();
-        qCDebug(kastsFeed) << name << email << url;
-        for (int i = 0; i < m_authors.count(); i++) {
-            qCDebug(kastsFeed) << "old authors" << m_authors[i]->name() << m_authors[i]->email() << m_authors[i]->url();
-            if (m_authors[i] && m_authors[i]->name() == name && m_authors[i]->email() == email && m_authors[i]->url() == url) {
-                existingAuthor = true;
-                newAuthors += m_authors[i];
-            }
-        }
-        if (!existingAuthor) {
-            newAuthors += new Author(name, email, url, nullptr);
-            haveAuthorsChanged = true;
-        }
+        authors += authorQuery.value(QStringLiteral("name")).toString();
     }
 
-    // Finally check whether m_authors and newAuthors are identical
-    // if not, then delete the authors that were removed
-    for (int i = 0; i < m_authors.count(); i++) {
-        if (!newAuthors.contains(m_authors[i])) {
-            delete m_authors[i];
-            haveAuthorsChanged = true;
-        }
+    if (authors.size() == 1) {
+        m_authors = authors[0];
+    } else if (authors.size() == 2) {
+        m_authors = i18nc("<name> and <name>", "%1 and %2", authors.first(), authors.last());
+    } else if (authors.size() > 2) {
+        auto last = authors.takeLast();
+        m_authors = i18nc("<name(s)>, and <name>", "%1, and %2", authors.join(u','), last);
     }
-
-    m_authors = newAuthors;
-
-    if (haveAuthorsChanged)
-        Q_EMIT authorsChanged(m_authors);
-    qCDebug(kastsFeed) << "feed" << m_name << "authors have changed?" << haveAuthorsChanged;
+    Q_EMIT authorsChanged(m_authors);
 }
 
 void Feed::updateUnreadEntryCountFromDB()
@@ -210,7 +204,7 @@ QString Feed::description() const
     return m_description;
 }
 
-QVector<Author *> Feed::authors() const
+QString Feed::authors() const
 {
     return m_authors;
 }
@@ -313,16 +307,6 @@ void Feed::setDescription(const QString &description)
     }
 }
 
-void Feed::setAuthors(const QVector<Author *> &authors)
-{
-    for (auto &author : m_authors) {
-        delete author;
-    }
-    m_authors.clear();
-    m_authors = authors;
-    Q_EMIT authorsChanged(m_authors);
-}
-
 void Feed::setDeleteAfterCount(int count)
 {
     m_deleteAfterCount = count;
